@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef IMAPRESOURCECAPABILITIESMANAGER_H
-#define IMAPRESOURCECAPABILITIESMANAGER_H
+#pragma once
 
 #include <QHash>
 #include <QObject>
@@ -41,5 +40,3 @@ private:
     QHash<QString, bool> mImapResource;
 };
 }
-
-#endif // IMAPRESOURCECAPABILITIESMANAGER_H
